Orange Network
==============

Orange Network is an add-on for Orange_ data mining software package. It
provides network visualization and analysis tools.

.. _Orange: http://orange.biolab.si/

Documentation is found at:

http://orange-network.readthedocs.org/

